@@ -1,4 +1,4 @@
-from typing import Callable, Dict, Union
+from typing import Callable, Dict, Optional, Union
 
 import jax
 import jax.numpy as jnp
@@ -206,6 +206,7 @@ class hmc:
         *,
         divergence_threshold: int = 1000,
         integrator: Callable = mcmc.integrators.velocity_verlet,
+        logprob_grad_fn: Optional[Callable] = None,
     ) -> SamplingAlgorithm:
 
         step = cls.kernel(integrator, divergence_threshold)
@@ -221,6 +222,7 @@ class hmc:
                 step_size,
                 inverse_mass_matrix,
                 num_integration_steps,
+                logprob_grad_fn=logprob_grad_fn,
             )
 
         return SamplingAlgorithm(init_fn, step_fn)
@@ -366,6 +368,7 @@ class nuts:
         max_num_doublings: int = 10,
         divergence_threshold: int = 1000,
         integrator: Callable = mcmc.integrators.velocity_verlet,
+        logprob_grad_fn: Optional[Callable] = None,
     ) -> SamplingAlgorithm:
 
         step = cls.kernel(integrator, divergence_threshold, max_num_doublings)
@@ -380,6 +383,7 @@ class nuts:
                 logprob_fn,
                 step_size,
                 inverse_mass_matrix,
+                logprob_grad_fn=logprob_grad_fn,
             )
 
         return SamplingAlgorithm(init_fn, step_fn)
@@ -393,6 +397,7 @@ def window_adaptation(
     initial_step_size: float = 1.0,
     target_acceptance_rate: float = 0.65,
     progress_bar: bool = False,
+    logprob_grad_fn: Optional[Callable] = None,
     **parameters,
 ) -> AdaptationAlgorithm:
     """Adapt the parameters of algorithms in the HMC family.
@@ -423,6 +428,9 @@ def window_adaptation(
         The acceptance rate that we target during step size adaptation.
     progress_bar
         Whether we should display a progress bar.
+    logprob_grad_fn
+        The gradient of logprob_fn.  If it's not provided, it will be computed
+        by jax using reverse mode autodiff (jax.grad).
     **parameters
         The extra parameters to pass to the algorithm, e.g. the number of
         integration steps for HMC.
@@ -443,6 +451,7 @@ def window_adaptation(
                 logprob_fn,
                 step_size,
                 inverse_mass_matrix,
+                logprob_grad_fn=logprob_grad_fn,
                 **parameters,
             )
 
@@ -464,7 +473,7 @@ def window_adaptation(
         return ((state, adaptation_state), (state, info, adaptation_state))
 
     def run(rng_key: PRNGKey, position: PyTree):
-        init_state = algorithm.init(position, logprob_fn)
+        init_state = algorithm.init(position, logprob_fn, logprob_grad_fn)
         init_warmup_state = init(init_state, initial_step_size)
 
         if progress_bar:
@@ -624,3 +633,63 @@ class orbital_hmc:
             )
 
         return SamplingAlgorithm(init_fn, step_fn)
+
+
+class elliptical_slice:
+    """Implements the (basic) user interface for the Elliptical Slice sampling kernel
+
+    Examples
+    --------
+
+    A new Elliptical Slice sampling kernel can be initialized and used with the following code:
+
+    .. code::
+
+        ellip_slice = blackjax.elliptical_slice(loglikelihood_fn, cov_matrix)
+        state = ellip_slice.init(position)
+        new_state, info = ellip_slice.step(rng_key, state)
+
+    We can JIT-compile the step function for better performance
+
+    .. code::
+
+        step = jax.jit(ellip_slice.step)
+        new_state, info = step(rng_key, state)
+
+    Parameters
+    ----------
+    loglikelihood_fn
+        Only the log likelihood function from the posterior distributon we wish to sample.
+    cov_matrix
+        The value of the covariance matrix of the gaussian prior distribution from the posterior we wish to sample.
+
+    Returns
+    -------
+    A ``SamplingAlgorithm``.
+
+    """
+
+    init = staticmethod(mcmc.elliptical_slice.init)
+    kernel = staticmethod(mcmc.elliptical_slice.kernel)
+
+    def __new__(  # type: ignore[misc]
+        cls,
+        loglikelihood_fn: Callable,
+        *,
+        mean: Array,
+        cov: Array,
+    ) -> SamplingAlgorithm:
+
+        step = cls.kernel(cov, mean)
+
+        def init_fn(position: PyTree):
+            return cls.init(position, loglikelihood_fn)
+
+        def step_fn(rng_key: PRNGKey, state):
+            return step(
+                rng_key,
+                state,
+                loglikelihood_fn,
+            )
+
+        return SamplingAlgorithm(init_fn, step_fn)
